summaryrefslogtreecommitdiff
path: root/plugins/NewEventNotify/src
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2021-12-26 20:31:39 +0300
committerGeorge Hazan <ghazan@miranda.im>2021-12-26 20:31:39 +0300
commitcddcd7483a7c472598af098e759e5d309024f606 (patch)
treeb0a227d6e087c41958cc84d27bc323353248aae5 /plugins/NewEventNotify/src
parent1039b2829a264280493ba0fa979214fe024dc70c (diff)
DWORD -> uint32_t
Diffstat (limited to 'plugins/NewEventNotify/src')
-rw-r--r--plugins/NewEventNotify/src/options.cpp6
-rw-r--r--plugins/NewEventNotify/src/popup.cpp10
2 files changed, 8 insertions, 8 deletions
diff --git a/plugins/NewEventNotify/src/options.cpp b/plugins/NewEventNotify/src/options.cpp
index a434392cfe..9bb9d51fdb 100644
--- a/plugins/NewEventNotify/src/options.cpp
+++ b/plugins/NewEventNotify/src/options.cpp
@@ -209,9 +209,9 @@ static INT_PTR CALLBACK OptionsDlgProc(HWND hWnd, UINT message, WPARAM wParam, L
g_plugin.bMenuitem = IsDlgButtonChecked(hWnd, IDC_CHKMENUITEM);
g_plugin.bDisable = IsDlgButtonChecked(hWnd, IDC_CHKDISABLE);
g_plugin.bPreview = IsDlgButtonChecked(hWnd, IDC_CHKPREVIEW);
- g_plugin.iDelayMsg = IsDlgButtonChecked(hWnd, IDC_CHKINFINITE_MESSAGE) ? -1 : (DWORD)GetDlgItemInt(hWnd, IDC_DELAY_MESSAGE, nullptr, FALSE);
- g_plugin.iDelayFile = IsDlgButtonChecked(hWnd, IDC_CHKINFINITE_FILE) ? -1 : (DWORD)GetDlgItemInt(hWnd, IDC_DELAY_FILE, nullptr, FALSE);
- g_plugin.iDelayOthers = IsDlgButtonChecked(hWnd, IDC_CHKINFINITE_OTHERS) ? -1 : (DWORD)GetDlgItemInt(hWnd, IDC_DELAY_OTHERS, nullptr, FALSE);
+ g_plugin.iDelayMsg = IsDlgButtonChecked(hWnd, IDC_CHKINFINITE_MESSAGE) ? -1 : (uint32_t)GetDlgItemInt(hWnd, IDC_DELAY_MESSAGE, nullptr, FALSE);
+ g_plugin.iDelayFile = IsDlgButtonChecked(hWnd, IDC_CHKINFINITE_FILE) ? -1 : (uint32_t)GetDlgItemInt(hWnd, IDC_DELAY_FILE, nullptr, FALSE);
+ g_plugin.iDelayOthers = IsDlgButtonChecked(hWnd, IDC_CHKINFINITE_OTHERS) ? -1 : (uint32_t)GetDlgItemInt(hWnd, IDC_DELAY_OTHERS, nullptr, FALSE);
g_plugin.bMergePopup = IsDlgButtonChecked(hWnd, IDC_CHKMERGEPOPUP);
g_plugin.bMsgWindowCheck = IsDlgButtonChecked(hWnd, IDC_CHKWINDOWCHECK);
g_plugin.bMsgReplyWindow = IsDlgButtonChecked(hWnd, IDC_CHKREPLYWINDOW);
diff --git a/plugins/NewEventNotify/src/popup.cpp b/plugins/NewEventNotify/src/popup.cpp
index b2bd6190f0..6fdb090a42 100644
--- a/plugins/NewEventNotify/src/popup.cpp
+++ b/plugins/NewEventNotify/src/popup.cpp
@@ -191,7 +191,7 @@ static wchar_t* GetEventPreview(DBEVENTINFO *dbei)
case EVENTTYPE_FILE:
if (dbei->pBlob) {
- char *p = (char*)dbei->pBlob + sizeof(DWORD);
+ char *p = (char*)dbei->pBlob + sizeof(uint32_t);
// filenames
comment2 = (dbei->flags & DBEF_UTF) ? mir_utf8decodeW(p) : mir_a2u(p);
p += mir_strlen(p) + 1;
@@ -229,8 +229,8 @@ static wchar_t* GetEventPreview(DBEVENTINFO *dbei)
case EVENTTYPE_ADDED:
// blob format is:
// DWORD numeric uin (ICQ only afaik)
// DWORD HANDLE to contact
// ASCIIZ nick (or text UID)
// ASCIIZ first name
// ASCIIZ last name
@@ -244,7 +244,7 @@ static wchar_t* GetEventPreview(DBEVENTINFO *dbei)
char *pszLast = pszFirst + mir_strlen(pszFirst) + 1;
char *pszEmail = pszLast + mir_strlen(pszLast) + 1;
- mir_snprintf(szUin, "%d", *((DWORD*)dbei->pBlob));
+ mir_snprintf(szUin, "%d", *((uint32_t*)dbei->pBlob));
if (mir_strlen(pszNick) > 0) {
if (dbei->flags & DBEF_UTF)
szNick = mir_utf8decodeW(pszNick);
@@ -257,7 +257,7 @@ static wchar_t* GetEventPreview(DBEVENTINFO *dbei)
else
szNick = mir_a2u(pszEmail);
}
- else if (*((DWORD*)dbei->pBlob) > 0)
+ else if (*((uint32_t*)dbei->pBlob) > 0)
szNick = mir_a2u(szUin);
if (szNick) {
@@ -229,8 +229,8 @@ static wchar_t* GetEventPreview(DBEVENTINFO *dbei)
case EVENTTYPE_ADDED:
// blob format is:
- // DWORD numeric uin (ICQ only afaik)
- // DWORD HANDLE to contact
+ // uint32_t numeric uin (ICQ only afaik)
+ // uint32_t HANDLE to contact
// ASCIIZ nick (or text UID)
// ASCIIZ first name